==> vmaid-2.1.7.tar.gz: vmaid-2.1.7/w32loader/w32updwn.h <==
/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __W32UPDWN_H__
#define __W32UPDWN_H__


#include "user32.h"


/* ja:スピンボタンコントロール */
#define UPDOWN_CLASSA "msctls_updown32"
#define UPDOWN_CLASSW (w32ldr_tchar_to_wc("msctls_updown32"))
#ifdef UNICODE
# define UPDOWN_CLASS UPDOWN_CLASSW
#else /* not UNICODE */
# define UPDOWN_CLASS UPDOWN_CLASSA
#endif /* not UNICODE */
#define UDS_WRAP        0x0001
#define UDS_SETBUDDYINT 0x0002
#define UDS_ALIGNRIGHT  0x0004
#define UDS_ALIGNLEFT   0x0008
#define UDS_AUTOBUDDY   0x0010
#define UDS_ARROWKEYS   0x0020
#define UDS_HORZ        0x0040
#define UDS_NOTHOUSANDS 0x0080
#define UDS_HOTTRACK    0x0100
#define UDM_SETRANGE         (WM_USER+101)
#define UDM_GETRANGE         (WM_USER+102)
#define UDM_SETPOS           (WM_USER+103)
#define UDM_GETPOS           (WM_USER+104)
#define UDM_SETBUDDY         (WM_USER+105)
#define UDM_GETBUDDY         (WM_USER+106)
#define UDM_SETACCEL         (WM_USER+107)
#define UDM_GETACCEL         (WM_USER+108)
#define UDM_SETBASE          (WM_USER+109)
#define UDM_GETBASE          (WM_USER+110)
#define UDM_SETRANGE32       (WM_USER+111)
#define UDM_GETRANGE32       (WM_USER+112)
#define UDM_SETUNICODEFORMAT CCM_SETUNICODEFORMAT
#define UDM_GETUNICODEFORMAT CCM_GETUNICODEFORMAT
#define UDM_SETPOS32         (WM_USER+113)
#define UDM_GETPOS32         (WM_USER+114)
#define UDN_FIRST    (-721)
#define UDN_LAST     (-740)
#define UDN_DELTAPOS (UDN_FIRST-1)
#include "pshpack1.h"
typedef struct _NM_UPDOWN
{
  NMHDR hdr;
  INT iPos;
  INT iDelta;
} NM_UPDOWN, *PNM_UPDOWN, *LPNM_UPDOWN;
typedef struct _UDACCEL
{
  UINT nSec;
  UINT nInc;
} UDACCEL, *PUDACCEL, *LPUDACCEL;
#include "poppack.h"


#endif /* not __W32UPDWN_H__ */

==> vmaid-2.1.9.tar.gz: vmaid-2.1.9/w32loader/w32updwn.h <==
/*
    w32loader
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __W32UPDWN_H__
#define __W32UPDWN_H__


#include "user32.h"


G_BEGIN_DECLS


/* ja:スピンボタンコントロール */
#define UPDOWN_CLASSA "msctls_updown32"
#define UPDOWN_CLASSW (w32ldr_tchar_to_wc("msctls_updown32"))
#ifdef UNICODE
# define UPDOWN_CLASS UPDOWN_CLASSW
#else /* not UNICODE */
# define UPDOWN_CLASS UPDOWN_CLASSA
#endif /* not UNICODE */
#define UDS_WRAP        0x0001
#define UDS_SETBUDDYINT 0x0002
#define UDS_ALIGNRIGHT  0x0004
#define UDS_ALIGNLEFT   0x0008
#define UDS_AUTOBUDDY   0x0010
#define UDS_ARROWKEYS   0x0020
#define UDS_HORZ        0x0040
#define UDS_NOTHOUSANDS 0x0080
#define UDS_HOTTRACK    0x0100
#define UDM_SETRANGE         (WM_USER+101)
#define UDM_GETRANGE         (WM_USER+102)
#define UDM_SETPOS           (WM_USER+103)
#define UDM_GETPOS           (WM_USER+104)
#define UDM_SETBUDDY         (WM_USER+105)
#define UDM_GETBUDDY         (WM_USER+106)
#define UDM_SETACCEL         (WM_USER+107)
#define UDM_GETACCEL         (WM_USER+108)
#define UDM_SETBASE          (WM_USER+109)
#define UDM_GETBASE          (WM_USER+110)
#define UDM_SETRANGE32       (WM_USER+111)
#define UDM_GETRANGE32       (WM_USER+112)
#define UDM_SETUNICODEFORMAT CCM_SETUNICODEFORMAT
#define UDM_GETUNICODEFORMAT CCM_GETUNICODEFORMAT
#define UDM_SETPOS32         (WM_USER+113)
#define UDM_GETPOS32         (WM_USER+114)
#define UDN_FIRST    (-721)
#define UDN_LAST     (-740)
#define UDN_DELTAPOS (UDN_FIRST-1)
#include "pshpack1.h"
typedef struct _NM_UPDOWN
{
  NMHDR hdr;
  INT iPos;
  INT iDelta;
} NM_UPDOWN, *PNM_UPDOWN, *LPNM_UPDOWN;
typedef struct _UDACCEL
{
  UINT nSec;
  UINT nInc;
} UDACCEL, *PUDACCEL, *LPUDACCEL;
#include "poppack.h"


G_END_DECLS


#endif /* not __W32UPDWN_H__ */
